@@ -748,13 +748,16 @@ meta_window_place (MetaWindow        *window,
       {
         MetaWindow *w = tmp->data;
 
-        if (!w->minimized &&
+        if (meta_window_showing_on_its_workspace (w) &&
             w != window && 
-            window->workspace == w->workspace)
+            (window->workspace == w->workspace ||
+             window->on_all_workspaces || w->on_all_workspaces))
           windows = g_list_prepend (windows, w);
 
         tmp = tmp->next;
       }
+
+    g_slist_free (all_windows);
   }
 
   /* Warning, this is a round trip! */
@@ -888,6 +891,8 @@ get_windows_on_same_workspace (MetaWindow *window,
   if (n_windows)
     *n_windows = i;
   
+  g_slist_free (all_windows);
+
   return windows;
 }
 
